package publiccapb
import "cloud.google.com/go/security/publicca/apiv1/publiccapb"
Index ¶
- Constants
- Variables
- func RegisterPublicCertificateAuthorityServiceServer(s grpc.ServiceRegistrar, srv PublicCertificateAuthorityServiceServer)
- type CreateExternalAccountKeyRequest
- func (*CreateExternalAccountKeyRequest) Descriptor() ([]byte, []int)
- func (x *CreateExternalAccountKeyRequest) GetExternalAccountKey() *ExternalAccountKey
- func (x *CreateExternalAccountKeyRequest) GetParent() string
- func (*CreateExternalAccountKeyRequest) ProtoMessage()
- func (x *CreateExternalAccountKeyRequest) ProtoReflect() protoreflect.Message
- func (x *CreateExternalAccountKeyRequest) Reset()
- func (x *CreateExternalAccountKeyRequest) String() string
- type ExternalAccountKey
- func (*ExternalAccountKey) Descriptor() ([]byte, []int)
- func (x *ExternalAccountKey) GetB64MacKey() []byte
- func (x *ExternalAccountKey) GetKeyId() string
- func (x *ExternalAccountKey) GetName() string
- func (*ExternalAccountKey) ProtoMessage()
- func (x *ExternalAccountKey) ProtoReflect() protoreflect.Message
- func (x *ExternalAccountKey) Reset()
- func (x *ExternalAccountKey) String() string
- type PublicCertificateAuthorityServiceClient
- type PublicCertificateAuthorityServiceServer
- type UnimplementedPublicCertificateAuthorityServiceServer
- type UnsafePublicCertificateAuthorityServiceServer
Constants ¶
const (
PublicCertificateAuthorityService_CreateExternalAccountKey_FullMethodName = "/google.cloud.security.publicca.v1.PublicCertificateAuthorityService/CreateExternalAccountKey"
)
Variables ¶
var File_google_cloud_security_publicca_v1_resources_proto protoreflect.FileDescriptor
var File_google_cloud_security_publicca_v1_service_proto protoreflect.FileDescriptor
var PublicCertificateAuthorityService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.security.publicca.v1.PublicCertificateAuthorityService", HandlerType: (*PublicCertificateAuthorityServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateExternalAccountKey", Handler: _PublicCertificateAuthorityService_CreateExternalAccountKey_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/security/publicca/v1/service.proto", }
PublicCertificateAuthorityService_ServiceDesc is the grpc.ServiceDesc for PublicCertificateAuthorityService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterPublicCertificateAuthorityServiceServer ¶
func RegisterPublicCertificateAuthorityServiceServer(s grpc.ServiceRegistrar, srv PublicCertificateAuthorityServiceServer)
Types ¶
type CreateExternalAccountKeyRequest ¶
type CreateExternalAccountKeyRequest struct {
// Required. The parent resource where this external_account_key will be
// created. Format: projects/[project_id]/locations/[location]. At present
// only the "global" location is supported.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. The external account key to create. This field only exists to
// future-proof the API. At present, all fields in ExternalAccountKey are
// output only and all values are ignored. For the purpose of the
// CreateExternalAccountKeyRequest, set it to a default/empty value.
ExternalAccountKey *ExternalAccountKey `protobuf:"bytes,2,opt,name=external_account_key,json=externalAccountKey,proto3" json:"external_account_key,omitempty"`
// contains filtered or unexported fields
}
Creates a new ExternalAccountKey[google.cloud.security.publicca.v1.ExternalAccountKey] in a given project.
func (*CreateExternalAccountKeyRequest) Descriptor ¶
func (*CreateExternalAccountKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateExternalAccountKeyRequest.ProtoReflect.Descriptor instead.
func (*CreateExternalAccountKeyRequest) GetExternalAccountKey ¶
func (x *CreateExternalAccountKeyRequest) GetExternalAccountKey() *ExternalAccountKey
func (*CreateExternalAccountKeyRequest) GetParent ¶
func (x *CreateExternalAccountKeyRequest) GetParent() string
func (*CreateExternalAccountKeyRequest) ProtoMessage ¶
func (*CreateExternalAccountKeyRequest) ProtoMessage()
func (*CreateExternalAccountKeyRequest) ProtoReflect ¶
func (x *CreateExternalAccountKeyRequest) ProtoReflect() protoreflect.Message
func (*CreateExternalAccountKeyRequest) Reset ¶
func (x *CreateExternalAccountKeyRequest) Reset()
func (*CreateExternalAccountKeyRequest) String ¶
func (x *CreateExternalAccountKeyRequest) String() string
type ExternalAccountKey ¶
type ExternalAccountKey struct {
// Output only. Resource name.
// projects/{project}/locations/{location}/externalAccountKeys/{key_id}
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Output only. Key ID.
// It is generated by the PublicCertificateAuthorityService
// when the ExternalAccountKey is created
KeyId string `protobuf:"bytes,2,opt,name=key_id,json=keyId,proto3" json:"key_id,omitempty"`
// Output only. Base64-URL-encoded HS256 key.
// It is generated by the PublicCertificateAuthorityService
// when the ExternalAccountKey is created
B64MacKey []byte `protobuf:"bytes,3,opt,name=b64_mac_key,json=b64MacKey,proto3" json:"b64_mac_key,omitempty"`
// contains filtered or unexported fields
}
A representation of an ExternalAccountKey used for [external account binding](https://tools.ietf.org/html/rfc8555#section-7.3.4) within ACME.
func (*ExternalAccountKey) Descriptor ¶
func (*ExternalAccountKey) Descriptor() ([]byte, []int)
Deprecated: Use ExternalAccountKey.ProtoReflect.Descriptor instead.
func (*ExternalAccountKey) GetB64MacKey ¶
func (x *ExternalAccountKey) GetB64MacKey() []byte
func (*ExternalAccountKey) GetKeyId ¶
func (x *ExternalAccountKey) GetKeyId() string
func (*ExternalAccountKey) GetName ¶
func (x *ExternalAccountKey) GetName() string
func (*ExternalAccountKey) ProtoMessage ¶
func (*ExternalAccountKey) ProtoMessage()
func (*ExternalAccountKey) ProtoReflect ¶
func (x *ExternalAccountKey) ProtoReflect() protoreflect.Message
func (*ExternalAccountKey) Reset ¶
func (x *ExternalAccountKey) Reset()
func (*ExternalAccountKey) String ¶
func (x *ExternalAccountKey) String() string
type PublicCertificateAuthorityServiceClient ¶
type PublicCertificateAuthorityServiceClient interface {
// Creates a new
// [ExternalAccountKey][google.cloud.security.publicca.v1.ExternalAccountKey]
// bound to the project.
CreateExternalAccountKey(ctx context.Context, in *CreateExternalAccountKeyRequest, opts ...grpc.CallOption) (*ExternalAccountKey, error)
}
PublicCertificateAuthorityServiceClient is the client API for PublicCertificateAuthorityService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPublicCertificateAuthorityServiceClient ¶
func NewPublicCertificateAuthorityServiceClient(cc grpc.ClientConnInterface) PublicCertificateAuthorityServiceClient
type PublicCertificateAuthorityServiceServer ¶
type PublicCertificateAuthorityServiceServer interface {
// Creates a new
// [ExternalAccountKey][google.cloud.security.publicca.v1.ExternalAccountKey]
// bound to the project.
CreateExternalAccountKey(context.Context, *CreateExternalAccountKeyRequest) (*ExternalAccountKey, error)
}
PublicCertificateAuthorityServiceServer is the server API for PublicCertificateAuthorityService service. All implementations should embed UnimplementedPublicCertificateAuthorityServiceServer for forward compatibility
type UnimplementedPublicCertificateAuthorityServiceServer ¶
type UnimplementedPublicCertificateAuthorityServiceServer struct {
}
UnimplementedPublicCertificateAuthorityServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedPublicCertificateAuthorityServiceServer) CreateExternalAccountKey ¶
func (UnimplementedPublicCertificateAuthorityServiceServer) CreateExternalAccountKey(context.Context, *CreateExternalAccountKeyRequest) (*ExternalAccountKey, error)
type UnsafePublicCertificateAuthorityServiceServer ¶
type UnsafePublicCertificateAuthorityServiceServer interface {
// contains filtered or unexported methods
}
UnsafePublicCertificateAuthorityServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PublicCertificateAuthorityServiceServer will result in compilation errors.
Source Files ¶
resources.pb.go service.pb.go service_grpc.pb.go
- Version
- v1.19.2 (latest)
- Published
- Sep 22, 2025
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 6 months ago –
Tools for package owners.